@@ -1,5 +1,7 @@
+import os
 from pathlib import Path
 
+from mne import concatenate_raws
 from mne.channels import read_custom_montage
 from mne.io import read_raw, read_raw_edf, Raw
 from mne.utils import logger
@@ -125,3 +127,34 @@ def filter_raw(raw: Raw, **kwargs) -> Raw:
     )
 
     return raw_bandpass
+
+
+def concat_raws_with_suffix(path_to_raw_files: str, suffix: str) -> Raw:
+    """
+    Concatenates raw measurement files with a given suffix (e.g. ".vhdr") from a folder.
+    File namings should follow an order e.g. the first part of the measurement is
+    "eeg_1.vhdr" and the second part is "eeg_1_2.vhdr".
+    Returns the concatenated instance as if it was a continuous measurement.
+    Parameters
+    ----------
+    path_to_raw_files: str
+        The path to the folder where the raw files are located.
+    suffix: str
+        The name of the file extension (e.g. ".vhdr", ".edf")
+    Returns
+    -------
+    Raw instance
+    """
+
+    raw_file_path = Path(path_to_raw_files)
+    file_names_in_order = sorted(
+        [Path(f).stem for f in os.listdir(path_to_raw_files) if f.endswith(suffix)])
+    files = [raw_file_path.joinpath(f + suffix) for f in file_names_in_order]
+
+    raws = [read_raw(file, preload=False, verbose=True) for file in files]
+    raw = concatenate_raws(raws)
+    # Session parameters
+    raw_id = file_names_in_order[0]
+    raw.info.update(temp=raw_id)
+
+    return raw
